@@ -7,17 +7,18 @@ SESSION_SQLALCHEMY_TABLE = 'sessions'
 # Create in-memory database
 DATABASE_FILE = 'sample_db.sqlite'
 SQLALCHEMY_DATABASE_URI = 'sqlite:///' + DATABASE_FILE
-SQLALCHEMY_TRACK_MODIFICATIONS = False
+SQLALCHEMY_TRACK_MODIFICATIONS = True
 
 # Create Security Config
-SECURITY_PASSWORD_SALT = '123456789'
+SECURITY_PASSWORD_SALT ='123456789'
 SECURITY_EMAIL_SENDER='admin@app'
 
 # Create EMail Configuration
 MAIL_SERVER=''
-MAIL_PORT=
+MAIL_PORT=0
 MAIL_USE_SSL=False
 MAIL_USERNAME=''
 MAIL_PASSWORD=''
 MAIL_USE_TLS=True
 
+
